@@ -38,7 +38,7 @@
 #include <gtk/gtk.h>
 #include <libwnck/libwnck.h>
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include "windowlist.h"
 #include "xfdesktop-common.h"
@@ -454,7 +454,7 @@ windowlist_attach(XfceDesktop *desktop)
 }
 
 void
-windowlist_cleanup()
+windowlist_cleanup(void)
 {
     /* notused */
 }
